@@ -15,7 +15,7 @@
 #'   Vector of task ids to restrict to.
 #' @inheritParams list_oml_data_sets
 #'
-#' @return (`data.table()`) of results, or `NULL` if no data set matches the criteria.
+#' @return (`data.table()`) of results, or a Null data.table if no task matches the criteria.
 #'
 #' @references
 #' `r format_bib("openml_r", "vanschoren2014")`
@@ -38,27 +38,13 @@ list_oml_tasks = function(task_id = NULL, number_instances = NULL, number_featur
   )
   limit = assert_count(limit, positive = TRUE, coerce = TRUE)
   dots = insert_named(discard(dots, is.null), list(...))
+  tab = get_paginated_table(dots, "task", limit)
 
-  chunk_size = 1000L
-  tab = data.table()
-
-  while (nrow(tab) < limit) {
-    dots$limit = min(limit - nrow(tab), chunk_size)
-    query = build_filter_query("task", dots)
-
-    result = get_json(query, status_ok = 412L)
-    if (is.null(result))
-      break
-
-    tab = rbind(tab, setDT(result$tasks$task))
-    dots$offset = dots$offset %??% 0L + chunk_size
+  if (nrow(tab)) {
+    setnames(tab, "did", "data_id")
+    qualities = transpose_name_value(tab$quality, as_integer = TRUE)
+    rcbind(remove_named(tab, c("task_type_id", "task_type_id", "format", "input", "quality")), qualities)
   }
 
-  if (nrow(tab) == 0L) {
-    return(NULL)
-  }
-
-  setnames(tab, "did", "data_id")
-  qualities = transpose_name_value(tab$quality, as_integer = TRUE)
-  rcbind(remove_named(tab, c("task_type_id", "task_type_id", "format", "input", "quality")), qualities)
+  return(tab)
 }
